mitol-django-core
---

This is the Open Learning Core app. It provides common functionality used across all our applications.

### Getting started

`pip install mitol-django-core`


### Configuration

- `MITOL_COMMON_USER_FACTORY` - (optional) set to the fully qualified path for a user model factory, otherwise a default based on `django.contrib.auth.models.User` is used
